************************************************
User Guide to to Network Automation with Ansible
************************************************

More content coming soon!

Who should use this guide?
================================================================================

This guide is intended for network engineers using Ansible for automation. It covers advanced topics. If you understand networks and Ansible, this guide is for you. You may read through the entire guide if you choose, or use the links below to find the specific information you need.

If you're new to Ansible, or new to using Ansible for network automation, start with the :doc:`Getting Started Guide<../getting_started/index>`.

.. toctree::
   :maxdepth: 2
